package compbio.controllers;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.annotation.InitBinder;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;


import compbio.cassandra.DataBase;
import compbio.statistic.CassandraRequester;
import compbio.statistic.StatisticsProt;

/**
 * @author Alexander Sherstnev
 * @author Natasha Sherstneva
 */
@Controller
public class DayStatisticsController {

	@RequestMapping(value = "/stat", method = RequestMethod.GET)
	public String initFindForm(Map<String, Object> model) {
		return "QueryJobsByDate";
	}

	@RequestMapping(value = "/stat/query", method = RequestMethod.GET)
	public String findJobsInPeriod(@RequestParam("data1") String date1, @RequestParam("data2") String date2,
			@RequestParam("option") String option, Map<String, Object> model) {
		final long startTime = System.currentTimeMillis();

		CassandraRequester cr = new CassandraRequester();
		if (option.equals("AllDates")) {
			Calendar cal = Calendar.getInstance();
			date1 = StatisticsProt.DateFormatYYMMDD(cr.earliestDate());
			date2 = cal.get(Calendar.YEAR) + "/" + (cal.get(Calendar.MONTH) + 1) + "/" + cal.get(Calendar.DAY_OF_MONTH);
		}
		model.put("data1", date1);
		model.put("data2", date2);
		List<DataBase> res = cr.countJobs(date1, date2);
		model.put("result", res);
		final long endTime = System.currentTimeMillis();
		model.put("timeExecution", (endTime - startTime));
		model.put("flag", option);
		return "/ReportJobsByDate";
	}
	
	@RequestMapping(value = "/stat/oneday", method = RequestMethod.GET)
	public String findJobsInOneDay(@RequestParam("date") String date, Map<String, Object> model) throws ParseException {
		final long startTime = System.currentTimeMillis();

		final SimpleDateFormat formaterDDMMYY = new SimpleDateFormat("dd/MM/yyyy");
		final SimpleDateFormat formaterYYMMDD = new SimpleDateFormat("yyyy/MM/dd");
		String date1 = formaterYYMMDD.format(new Date(formaterDDMMYY.parse(date).getTime()));
	
		CassandraRequester cr = new CassandraRequester();
		List<DataBase> r1 = cr.countJobs(date1, date1);
		List<DataBase> r = cr.readJobByDay(date);
		model.put("results", r);
		model.put("njobs", r.size());
		model.put("date", date1);
		final long endTime = System.currentTimeMillis();
		model.put("timeExecution", (endTime - startTime));
		System.out.println("Request for date = " + date1 + ": " + r.size() + " jobs found");
		return "/ReportJobsOfOneDay";
	}
}
